@@ -1,8 +1,8 @@
-.checkICWithWarning <- function(IC, L2Fam, tol){
+.checkICWithWarning <- function(IC, L2Fam, tol, ...){
           if(!missing(L2Fam)){
-             prec <- checkIC(IC, L2Fam, out = FALSE)
+             prec <- checkIC(IC, L2Fam, out = FALSE, ...)
           }else{
-             prec <- checkIC(IC, out = FALSE)
+             prec <- checkIC(IC, out = FALSE, ...)
           }
           if(prec > tol)
             warning("The maximum deviation from the exact IC properties is ", prec,
@@ -17,17 +17,17 @@ setMethod("getRiskIC", signature(IC = "HampIC",
                                  risk = "asCov",
                                  neighbor = "missing",
                                  L2Fam = "missing"),
-    function(IC, risk, withCheck= TRUE){
+    function(IC, risk, withCheck= TRUE, ...){
         L2Fam <- force(eval(IC@CallL2Fam))
         if(missing(withCheck)) withCheck <- TRUE
-        getRiskIC(IC = IC, risk = risk, L2Fam = L2Fam, withCheck= withCheck)
+        getRiskIC(IC = IC, risk = risk, L2Fam = L2Fam, withCheck= withCheck, ...)
     })
 
 setMethod("getRiskIC", signature(IC = "HampIC", 
                                  risk = "asCov",
                                  neighbor = "missing",
                                  L2Fam = "L2ParamFamily"),
-    function(IC, risk, L2Fam, withCheck= TRUE){
+    function(IC, risk, L2Fam, withCheck= TRUE, ...){
         if(missing(withCheck)) withCheck <- TRUE
         Cov <- eval(IC@Risks[["asCov"]])
         if(is.null(Cov)){
@@ -39,11 +39,11 @@ setMethod("getRiskIC", signature(IC = "HampIC",
               neighbor <- ContNeighborhood(1)
               Cov <- getInfV(L2deriv = L2deriv, neighbor = neighbor,
                          biastype = biastype(IC), clip = c0, cent = z, stand = A)
-              if(withCheck) .checkICWithWarning(IC, L2Fam, tol=.Machine$double.eps^.25)
+              if(withCheck) .checkICWithWarning(IC, L2Fam, tol=.Machine$double.eps^.25, ...)
               return(list(asCov = list(distribution = .getDistr(L2Fam),
                           value = Cov)))
             }
-            return(getRiskIC(as(IC, "IC"), risk = risk, L2Fam = L2Fam, withCheck= withCheck))
+            return(getRiskIC(as(IC, "IC"), risk = risk, L2Fam = L2Fam, withCheck= withCheck, ...))
         }else
             return(list(asCov = list(distribution = .getDistr(L2Fam), value = Cov)))
     })
@@ -52,7 +52,7 @@ setMethod("getRiskIC", signature(IC = "TotalVarIC",
                                  risk = "asCov",
                                  neighbor = "missing",
                                  L2Fam = "L2ParamFamily"),
-    function(IC, risk, L2Fam, withCheck = TRUE){
+    function(IC, risk, L2Fam, withCheck = TRUE, ...){
         Cov <- eval(IC@Risks[["asCov"]])
         if(missing(withCheck)) withCheck <- TRUE
         if (is.null(Cov)){
@@ -61,7 +61,7 @@ setMethod("getRiskIC", signature(IC = "TotalVarIC",
             c0 <- (IC@clipUp-IC@clipLo)/abs(A)
             z <- IC@clipLo/abs(A)
             neighbor <- TotalVarNeighborhood(1)
-            if(withCheck) .checkICWithWarning(IC, L2Fam, tol=.Machine$double.eps^.25)
+            if(withCheck) .checkICWithWarning(IC, L2Fam, tol=.Machine$double.eps^.25, ...)
             Cov <- getInfV(L2deriv = L2deriv, neighbor = neighbor,
                        biastype = biastype(IC), clip = c0, cent = z, stand = A)
             }
@@ -73,7 +73,7 @@ setMethod("getRiskIC", signature(IC = "TotalVarIC",
 ###############################################################################
 setMethod("getBiasIC", signature(IC = "HampIC",
                                  neighbor = "UncondNeighborhood"),
-    function(IC, neighbor, L2Fam,..., withCheck = TRUE){
+    function(IC, neighbor, L2Fam,...){
         if(missing(L2Fam))
             L2Fam <- force(eval(IC@CallL2Fam))
 
@@ -85,7 +85,7 @@ setMethod("getBiasIC", signature(IC = "HampIC",
 
 setMethod("getBiasIC", signature(IC = "TotalVarIC",
                                  neighbor = "UncondNeighborhood"),
-    function(IC, neighbor, L2Fam,..., withCheck = TRUE){
+    function(IC, neighbor, L2Fam,...){
         if(missing(L2Fam))
             L2Fam <- force(eval(IC@CallL2Fam))
 
